<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => 'Vi&#7879;t Nam [vi]',
'0_liste' => 'spip-vi@rezo.net',
'0_mainteneur' => 'daoduyp@libertysurf.fr',

// A
'access_interface_graphique' => 'Tr&#7903; l&#7841;i giao di&#7879;n &#7843;nh ',
'access_mode_texte' => 'Xem ph&#7847;n giao di&#7879;n &#273;&#417;n gi&#7843;n',
'admin_debug' => 'debug',
'admin_modifier_article' => 'S&#7917;a &#273;&#7893;i b&agrave;i n&agrave;y',
'admin_modifier_auteur' => 'S&#7917;a &#273;&#7893;i t&aacute;c gi&#7843; n&agrave;y',
'admin_modifier_breve' => 'S&#7917;a &#273;&#7893;i tin ng&#7855;n n&agrave;y',
'admin_modifier_mot' => 'S&#7917;a &#273;&#7893;i t&#7915; then ch&#7889;t n&agrave;y',
'admin_modifier_rubrique' => 'S&#7917;a &#273;&#7893;i &#273;&#7873; m&#7909;c n&agrave;y',
'admin_recalculer' => 'C&#7853;p nh&#7853;t trang n&agrave;y',
'afficher_trad' => 'xem c&aacute;c b&#7843;n d&#7883;ch',
'alerte_maj_impossible' => '<b>B&aacute;o &#272;&#7897;ng!</b> Kh&ocirc;ng c&#7853;p nh&#7853;t database SQL l&ecirc;n &#7845;n b&#7843;n @version@ &#273;&#432;&#7907;c, c&oacute; th&#7875; l&agrave;  v&igrave; kh&ocirc;ng &#273;&#7911; quy&#7873;n h&#7841;n. Xin li&ecirc;n l&#7841;c v&#7899;i ISP.',
'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute; par ailleurs. La valeur actuelle est&nbsp;:', # MODIF
'analyse_xml' => 'Ph&acirc;n t&aacute;ch XML',
'annuler' => 'Xo&aacute;',
'antispam_champ_vide' => '&#272;&#7875; tr&#7889;ng &ocirc; n&agrave;y:',
'articles_recents' => 'Nh&#7919;ng b&agrave;i m&#7899;i nh&#7845;t',
'avis_archive_incorrect' => 'H&#7891; s&#417; n&agrave;y kh&ocirc;ng ph&#7843;i l&agrave; m&#7897;t h&#7891; s&#417; SPIP',
'avis_archive_invalide' => 'H&#7891; s&#417; n&agrave;y kh&ocirc;ng c&oacute; h&#7907;p l&yacute;',
'avis_attention' => 'L&#431;U &Yacute;!',
'avis_champ_incorrect_type_objet' => 'T&ecirc;n field @name@ kh&ocirc;ng &#273;&uacute;ng cho d&#7841;ng @type@',
'avis_colonne_inexistante' => 'Kh&ocirc;ng c&oacute; c&#7897;t n&agrave;o t&ecirc;n @col@',
'avis_echec_syndication_01' => 'Xu&#7845;t b&#7843;n th&#7845;t b&#7841;i: v&igrave; backend kh&ocirc;ng &#273;&#7885;c &#273;&#432;&#7907;c ho&#7863;c n&oacute; kh&ocirc;ng cho ra b&agrave;i n&agrave;o c&#7843;.',
'avis_echec_syndication_02' => 'Xu&#7845;t b&#7843;n th&#7845;t b&#7841;i: kh&ocirc;ng th&#7875; n&#7889;i v&agrave;o backend c&#7911;a trang web n&agrave;y.',
'avis_erreur' => 'C&Oacute; L&#7894;I: xem d&#432;&#7899;i &#273;&acirc;y',
'avis_erreur_connexion' => 'C&oacute; L&#7895;i: kh&ocirc;ng n&#7889;i &#273;&#432;&#7907;c',
'avis_erreur_cookie' => 'C&oacute; l&#7895;i cookie',
'avis_erreur_fonction_contexte' => 'C&oacute; l&#7895;i programming. Function n&agrave;y kh&ocirc;ng n&ecirc;n d&ugrave;ng trong b&#7889;i c&#7843;nh n&agrave;y.', # MODIF
'avis_erreur_mysql' => 'C&oacute; L&#7895;i-SQL', # MODIF
'avis_erreur_sauvegarde' => 'L&#7895;i trong backup (@type@ @id_objet@)!',
'avis_erreur_visiteur' => 'Probl&egrave;me d\'acc&egrave;s &agrave; l\'espace priv&eacute;', # NEW

// B
'barre_a_accent_grave' => '&#272;&aacute;nh v&agrave;o ch&#7919; &Agrave;',
'barre_aide' => 'S&#7917; d&#7909;ng c&aacute;ch x&#7871;p b&agrave;i t&#7855;t &#273;&#7875; tr&igrave;nh b&agrave;y v&#259;n b&#7843;n',
'barre_e_accent_aigu' => '&#272;&aacute;nh v&agrave;o ch&#7919; &Eacute;',
'barre_eo' => '&#272;&aacute;nh v&agrave;o ch&#7919; oe',
'barre_eo_maj' => '&#272;&aacute;nh v&agrave;o ch&#7919; OE',
'barre_euro' => 'Th&ecirc;m ch&#7919; &euro;',
'barre_gras' => 'L&agrave;m ch&#7919; {{&#273;&#7853;m l&ecirc;n}}',
'barre_guillemets' => 'Cho ch&#7919; v&agrave;o gi&#7919;a hai d&#7845;u &laquo;  &raquo;',
'barre_guillemets_simples' => 'Cho ch&#7919; v&agrave;o gi&#7919;a hai d&#7845;u &#147;&nbsp;&#148;',
'barre_intertitre' => '&#272;&#7893;i th&agrave;nh {{{Ch&#7911; &#273;&#7873; ph&#7909;}}}',
'barre_italic' => 'L&agrave;m ch&#7919; {nghi&ecirc;ng}',
'barre_lien' => '&#272;&#7893;i th&agrave;nh [hyperlink-&gt;http://...]',
'barre_lien_input' => 'Xin cho v&agrave;o &#273;&#7883;a ch&#7881; hyperlink (b&#7841;n c&oacute; th&#7875; d&ugrave;ng Internet URL trong d&#7841;ng http://www.mysite.com/ ho&#7863;c l&agrave; s&#7889; b&agrave;i c&#7911;a trang web n&agrave;y).',
'barre_note' => '&#272;&#7893;i th&agrave;nh [[Ghi ch&uacute;]]',
'barre_paragraphe' => 'Cr&#233;er un paragraphe', # NEW
'barre_quote' => '<quote>Tr&iacute;ch d&#7851;n m&#7897;t &#273;o&#7841;n v&#259;n</quote>',
'bouton_ajouter_document' => 'TH&Ecirc;M T&Agrave;I LI&#7878;U', # MODIF
'bouton_ajouter_image' => 'TH&Ecirc;M H&Igrave;NH', # MODIF
'bouton_ajouter_image_document' => 'Ajouter une image ou&nbsp;un&nbsp;document', # NEW
'bouton_changer' => 'Thay &#273;&#7893;i',
'bouton_chercher' => 'T&igrave;m',
'bouton_choisir' => 'Ch&#7885;n',
'bouton_download' => 'T&eacute;l&eacute;charger', # NEW
'bouton_enregistrer' => 'L&#432;u Tr&#7919;',
'bouton_radio_desactiver_messagerie_interne' => 'Kh&ocirc;ng s&#7917; d&#7909;ng th&#432; t&iacute;n n&#7897;i b&#7897; ',
'bouton_radio_envoi_annonces' => 'G&#7917;i th&ocirc;ng b&aacute;o &#273;&#7871;n Ban Bi&ecirc;n T&#7853;p',
'bouton_radio_non_envoi_annonces' => 'Kh&ocirc;ng g&#7917;i th&ocirc;ng b&aacute;o',
'bouton_radio_non_envoi_liste_nouveautes' => 'Kh&ocirc;ng g&#7917;i tin t&#7913;c m&#7899;i nh&#7845;t',
'bouton_recharger_page' => 'N&#7841;p l&#7841;i trang n&agrave;y',
'bouton_telecharger' => '&#272;em l&ecirc;n',
'bouton_valider' => 'C&#7853;p nh&#7853;t',

// C
'cal_apresmidi' => 'bu&#7893;i chi&#7873;u',
'cal_jour_entier' => 'nguy&ecirc;n ng&agrave;y',
'cal_matin' => 's&aacute;ng',
'cal_par_jour' => 'l&#7883;ch tr&igrave;nh h&agrave;ng ng&agrave;y',
'cal_par_mois' => 'l&#7883;ch tr&igrave;nh h&agrave;ng th&aacute;ng',
'cal_par_semaine' => 'l&#7883;ch tr&igrave;nh h&agrave;ng tu&#7847;n',
'choix_couleur_interface' => 'm&agrave;u',
'choix_interface' => 'ch&#7885;n l&#7921;a dao di&#7879;n',
'colonne' => 'C&#7897;t',
'confirm_changer_statut' => 'C&#7847;n x&aacute;c nh&#7853;n: b&#7841;n y&ecirc;u c&#7847;u thay &#273;&#7893;i t&igrave;nh tr&#7841;ng c&#7911;a b&agrave;i n&agrave;y. B&#7841;n c&oacute; mu&#7889;n ti&#7871;p t&#7909;c kh&ocirc;ng?',
'correcte' => '&#273;&uacute;ng',

// D
'date_aujourdhui' => 'h&ocirc;m nay',
'date_avant_jc' => 'tr&#432;&#7899;c C&ocirc;ng Nguy&ecirc;n',
'date_dans' => 'trong @delai@',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'ng&agrave;y mai',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ v&agrave;o l&uacute;c @heure@',
'date_fmt_jour_mois' => '@jour@ @nommois@',
'date_fmt_jour_mois_annee' => '@jour@, @nommois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => 'v&agrave;o @nomjour@ @date@',
'date_heures' => 'gi&#7901;',
'date_hier' => 'h&ocirc;m qua',
'date_il_y_a' => 'c&aacute;ch &#273;&acirc;y @delai@',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'Ch&#7911; Nh&#7853;t',
'date_jour_1_abbr' => 'CN',
'date_jour_1_initiale' => 'CN',
'date_jour_2' => 'Th&#7913; Hai',
'date_jour_2_abbr' => 'T.Hai',
'date_jour_2_initiale' => 'T2',
'date_jour_3' => 'Th&#7913; Ba',
'date_jour_3_abbr' => 'T.Ba',
'date_jour_3_initiale' => 'T3',
'date_jour_4' => 'Th&#7913; T&#432;',
'date_jour_4_abbr' => 'T.T&#432;',
'date_jour_4_initiale' => 'T4',
'date_jour_5' => 'Th&#7913; N&#259;m',
'date_jour_5_abbr' => 'T.N&#259;m',
'date_jour_5_initiale' => 'T5',
'date_jour_6' => 'Th&#7913; S&aacute;u',
'date_jour_6_abbr' => 'T.S&aacute;u',
'date_jour_6_initiale' => 'T6',
'date_jour_7' => 'Th&#7913; B&#7843;y',
'date_jour_7_abbr' => 'T.B&#7843;y',
'date_jour_7_initiale' => 'T7',
'date_jours' => 'ng&agrave;y',
'date_minutes' => 'ph&uacute;t',
'date_mois' => 'th&aacute;ng',
'date_mois_1' => 'Th&aacute;ng Gi&ecirc;ng',
'date_mois_10' => 'Th&aacute;ng M&#432;&#7901;i',
'date_mois_11' => 'Th&aacute;ng M&#432;&#7901;i M&#7897;t',
'date_mois_12' => 'Th&aacute;ng M&#432;&#7901;i Hai',
'date_mois_2' => 'Th&aacute;ng Hai',
'date_mois_3' => 'Th&aacute;ng Ba',
'date_mois_4' => 'Th&aacute;ng T&#432;',
'date_mois_5' => 'Th&aacute;ng N&#259;m',
'date_mois_6' => 'Th&aacute;ng S&aacute;u',
'date_mois_7' => 'Th&aacute;ng B&#7843;y',
'date_mois_8' => 'Th&aacute;ng T&aacute;m',
'date_mois_9' => 'Th&aacute;ng Ch&iacute;n',
'date_saison_1' => 'm&ugrave;a &#273;&ocirc;ng',
'date_saison_2' => 'm&ugrave;a xu&acirc;n',
'date_saison_3' => 'm&ugrave;a h&egrave;',
'date_saison_4' => 'm&ugrave;a thu',
'date_secondes' => 'secondes', # NEW
'date_semaines' => 'tu&#7847;n',
'date_un_mois' => 'mois', # NEW
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => ' &#273;&#7875; th&#7921;c s&#7921; b&#7855;t &#273;&#7847;u vi&#7879;c thi&#7871;t tr&iacute;',
'dirs_preliminaire' => 'Ti&ecirc;n kh&#7903;i: <b>Thi&#7871;t k&#7871; quy&#7873;n h&#7841;n ra/v&ocirc;</b>',
'dirs_probleme_droits' => 'C&oacute; v&#7845;n &#273;&#7873; v&#7899;i quy&#7873;n h&#7841;n ra/v&ocirc;',
'dirs_repertoires_absents' => '<b>Kh&ocirc;ng t&igrave;m th&#7845;y c&aacute;c ng&#259;n ch&#7913;a sau &#273;&acirc;y: <ul>@bad_dirs@.</ul> </b>
  <p>C&oacute; th&#7875; l&agrave; v&igrave; kh&aacute;c bi&#7879;t ch&#7919; th&#432;&#7901;ng, ch&#7919; HOA.
  Xin xem l&#7841;i c&aacute;ch &#273;&aacute;nh v&#7847;n t&ecirc;n c&aacute;c ng&#259;n ch&#7913;a n&agrave;y cho &#273;&uacute;ng.
  N&#7871;u c&#7847;n ph&#7843;i s&#7917;a, d&ugrave;ng FTP &#273;&#7875; s&#7917;a.
  </p><p>Sau &#273;&oacute;, b&#7841;n c&oacute; th&#7875;</p>', # MODIF
'dirs_repertoires_suivants' => '<b>Nh&#7919;ng ng&#259;n sau &#273;&acirc;y kh&ocirc;ng &#273;&#432;&#7907;c ph&eacute;p Vi&#7871;t: <ul>@bad_dirs@.</ul> </b>

<p>&#272;&#7875; thay &#273;&#7893;i, d&ugrave;ng FTP v&agrave;o thay &#273;&#7893;i quy&#7873;n h&#7841;n ra/v&ocirc; c&#7911;a t&#7915;ng ng&#259;n. Th&#7875; th&#7913;c n&agrave;y c&oacute; ghi trong c&#7849;m nang s&#7917; d&#7909;ng.
</p><p>Khi n&agrave;o th&#7921;c hi&#7879;n xong, b&#7841;n c&oacute; th&#7875;</p>', # MODIF
'double_occurrence' => 'Hai l&#7847;n', # MODIF

// E
'en_cours' => 'en cours', # NEW
'entree_dimensions' => 'Kh&#7893;:',
'entree_titre_document' => 'T&#7921;a b&agrave;i h&#7891; s&#417;:',
'entree_titre_image' => 'T&#7921;a &#273;&#7873; h&igrave;nh:',
'envoi_via_le_site' => 'G&#7917;i t&#7915; trang web',
'erreur' => 'L&#7895;i',
'erreur_balise_non_fermee' => 'tag cu&#7889;i c&ugrave;ng ch&#432;a &#273;&oacute;ng:',
'erreur_texte' => 'l&#7895;i',
'etape' => '&Eacute;tape', # NEW

// F
'fichier_introuvable' => 'Kh&ocirc;ng t&igrave;m r&agrave; h&#7891; s&#417; @fichier@',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'B&#7841;n &#273;&atilde; ghi danh r&#7891;i.',
'form_email_non_valide' => '&#272;&#7883;a ch&#7881; email c&#7911;a b&#7841;n kh&ocirc;ng &#273;&uacute;ng.',
'form_forum_access_refuse' => 'B&#7841;n kh&ocirc;ng c&oacute; quy&#7873;n v&agrave;o trang web n&agrave;y n&#7919;a.',
'form_forum_bonjour' => 'Ch&agrave;o b&#7841;n @nom@,',
'form_forum_email_deja_enregistre' => '&#272;&#7883;a ch&#7881; email n&agrave;y &#273;&atilde; d&ugrave;ng ghi danh r&#7891;i, b&#7841;n c&oacute; th&#7875; d&ugrave;ng m&#7853;t m&atilde; c&#7911;a b&#7841;n.',
'form_forum_identifiant_mail' => 'Danh t&aacute;nh (ID) m&#7899;i c&#7911;a b&#7841;n &#273;&atilde; &#273;&#432;&#7907;c g&#7917;i b&#7857;ng email.',
'form_forum_identifiants' => 'Danh t&aacute;nh (ID) c&aacute; nh&acirc;n',
'form_forum_indiquer_nom_email' => 'Cho v&agrave;o t&ecirc;n v&agrave; &#273;&#7883;a ch&#7881; email c&#7911;a b&#7841;n. B&#7841;n s&#7869; nh&#7853;n &#273;&#432;&#7907;c danh t&aacute;nh (ID) c&aacute; nh&acirc;n qua email sau &#273;&oacute;.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(&#273;&acirc;y l&agrave; th&#432; t&iacute;n t&#7921; &#273;&#7897;ng)',
'form_forum_pass' => 'm&#7853;t m&atilde;:',
'form_forum_probleme_mail' => 'C&oacute; v&#7845;n &#273;&#7873; v&#7899;i email: T&ecirc;n g&#7885;i (ID) kh&ocirc;ng g&#7917;i &#273;i &#273;&#432;&#7907;c.',
'form_forum_voici1' => '&#272;&acirc;y l&agrave; t&ecirc;n g&#7885;i c&#7911;a b&#7841;n &#273;&#7875; tham gia v&agrave;o c&aacute;c di&#7877;n &#273;&agrave;n
"@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => '&#272;&acirc;y l&agrave; t&ecirc;n g&#7885;i c&#7911;a b&#7841;n &#273;&#7875; n&#7897;p b&agrave;i v&agrave;o trang web 
"@nom_site_spip@"(@adresse_login@):',
'form_indiquer_email' => 'Xin cho v&agrave;o &#273;&#7883;a ch&#7881; email c&#7911;a b&#7841;n.',
'form_indiquer_nom' => 'Xin cho v&agrave;o t&ecirc;n b&#7841;n.',
'form_indiquer_nom_site' => 'Xin cho v&agrave;o t&ecirc;n c&#7911;a website b&#7841;n.',
'form_pet_adresse_site' => 'URL c&#7911;a website b&#7841;n',
'form_pet_aucune_signature' => 'Kh&ocirc;ng k&yacute; hi&#7879;u n&agrave;o ph&ugrave; h&#7907;p v&#7899;i m&atilde; s&#7889; n&agrave;y...',
'form_pet_confirmation' => 'Xin x&aacute;c nh&#7853;n ch&#7919; k&yacute; c&#7911;a b&#7841;n:',
'form_pet_deja_enregistre' => 'Website n&agrave;y &#273;&atilde; &#273;&#432;&#7907;c ghi danh',
'form_pet_deja_signe' => 'B&#7841;n &#273;&atilde; k&yacute; v&#259;n b&#7843;n n&agrave;y.',
'form_pet_envoi_mail_confirmation' => 'M&#7897;t email x&aacute;c nh&#7853;n &#273;&atilde; &#273;&#432;&#7907;c g&#7917;i cho b&#7841;n. B&#7841;n n&ecirc;n v&agrave;o &#273;&#7883;a ch&#7881; URL &#273;&#7873; c&#7853;p trong email &#273;&oacute; &#273;&#7875; x&aacute;c nh&#7853;n ch&#7919; k&yacute; c&#7911;a m&igrave;nh.', # MODIF
'form_pet_mail_confirmation' => 'Ch&agrave;o b&#7841;n,

B&#7841;n y&ecirc;u c&#7847;u k&yacute; v&agrave;o th&#7881;nh nguy&#7879;n th&#432; @titre@.

B&#7841;n cung c&#7845;p c&aacute;c chi ti&#7871;t sau:
    T&ecirc;n: @nom_email@
    Web: @nom_site@ - @url_site@

QUAN TR&#7884;NG...
&#272;&#7875; x&aacute;c nh&#7853;n ch&#7919; k&yacute; c&#7911;a b&#7841;n, v&agrave; &#273;&#7883;a ch&#7881; sau &#273;&acirc;y (n&#7871;u kh&ocirc;ng, l&#7901;i y&ecirc;u c&#7847;u c&#7911;a b&#7841;n s&#7869; b&#7883; t&#7915; ch&#7889;i):
    @url@

C&aacute;m &#417;n s&#7921; tham gia c&#7911;a b&#7841;n.', # MODIF
'form_pet_message_commentaire' => 'C&oacute; nh&#7855;n tin hay b&igrave;nh lu&#7853;n g&igrave; kh&ocirc;ng?',
'form_pet_nom_site2' => 'T&ecirc;n trang web c&#7911;a b&#7841;n',
'form_pet_probleme_liens' => 'S&#7917;a &#273;&#7893;i ph&#7847;n n&#7897;i dung, xin l&#7845;y ra c&aacute;c hyperlink.',
'form_pet_probleme_technique' => 'Tr&#7909;c tr&#7863;c k&#7929; thu&#7853;t, ch&#7919; k&yacute; b&#7883; &#273;&igrave;nh tr&#7879; trong gi&acirc;y l&aacute;t.',
'form_pet_signature_pasprise' => 'Ch&#7919; k&yacute; b&#7841;n &#273;&atilde; b&#7883; l&#7901; &#273;i.',
'form_pet_signature_validee' => 'Ch&#7919; k&yacute; b&#7841;n &#273;&#432;&#7907;c x&aacute;c nh&#7853;n. C&aacute;m &#417;n b&#7841;n!',
'form_pet_site_deja_enregistre' => 'Website n&agrave;y &#273;&atilde; &#273;&#432;&#7907;c ghi danh',
'form_pet_url_invalide' => 'URL b&#7841;n cho v&agrave;o kh&ocirc;ng &#273;&uacute;ng.',
'form_pet_votre_email' => '&#272;&#7883;a ch&#7881; email c&#7911;a b&#7841;n',
'form_pet_votre_nom' => 'T&ecirc;n hay b&iacute; danh',
'form_pet_votre_site' => 'N&#7871;u b&#7841;n c&oacute; m&#7897;t trang web, b&#7841;n c&oacute; th&#7875; cho bi&#7871;t t&ecirc;n c&#7911;a n&oacute; d&#432;&#7899;i &#273;&acirc;y',
'form_prop_confirmer_envoi' => 'X&aacute;c nh&#7853;n th&ocirc;ng b&aacute;o g&#7917;i &#273;i',
'form_prop_description' => 'M&ocirc; t&#7843;/b&igrave;nh lu&#7853;n',
'form_prop_enregistre' => '&#272;&#7873; ngh&#7883; c&#7911;a b&#7841;n &#273;&atilde; &#273;&#432;&#7907;c ghi nh&#7853;n, n&oacute; s&#7869; xu&#7845;t hi&#7879;n online sau khi &#273;&#432;&#7907;c qu&#7843;n tr&#7883; vi&ecirc;n th&ocirc;ng qua.',
'form_prop_envoyer' => 'G&#7917;i th&#432; t&iacute;n',
'form_prop_indiquer_email' => 'Xin cho v&agrave;o &#273;&#7883;a ch&#7881; email',
'form_prop_indiquer_nom_site' => 'Xin cho v&agrave;o t&ecirc;n c&#7911;a trang web.',
'form_prop_indiquer_sujet' => 'Xin &#273;i&#7873;n v&agrave;o t&#7921;a &#273;&#7873;',
'form_prop_message_envoye' => '&#272;&atilde; g&#7917;i th&#432; t&iacute;n',
'form_prop_nom_site' => 'T&ecirc;n trang web',
'form_prop_non_enregistre' => '&#272;&#7873; ngh&#7883; c&#7911;a b&#7841;n ch&#432;a &#273;&#432;&#7907;c l&#432;u tr&#7919;.',
'form_prop_sujet' => 'T&#7921;a &#273;&#7873;',
'form_prop_url_site' => 'URL c&#7911;a trang web',
'forum_acces_refuse' => 'B&#7841;n kh&ocirc;ng c&oacute; quy&#7873;n v&agrave;o c&aacute;c di&#7877;n &#273;&agrave;n n&agrave;y n&#7919;a.',
'forum_attention_dix_caracteres' => '<b>C&#7843;nh b&aacute;o!</b> Th&#432; t&iacute;n qu&aacute; ng&#7855;n - Ph&#7843;i h&#417;n 10 m&#7851;u t&#7921;.',
'forum_attention_trois_caracteres' => '<b>C&#7843;nh b&aacute;o!</b> T&#7921;a &#273;&#7873; qu&aacute; ng&#7855;n - Ph&#7843;i h&#417;n 3 m&#7851;u t&#7921;.',
'forum_attention_trop_caracteres' => '<b>C&#7843;nh b&aacute;o&nbsp;!</b> n&#7897;i dung th&#432; t&iacute;n c&#7911;a b&#7841;n qu&aacute; d&agrave;i (@compte@ m&#7851;u t&#7921;)&nbsp;: &#273;&#7875; c&oacute; th&#7875; l&#432;u tr&#7919;, &#273;&#7897; d&agrave;i c&#7911;a n&#7897;i dung th&#432; t&iacute;n kh&ocirc;ng &#273;&#432;&#7907;c qu&aacute; @max@ m&#7851;u t&#7921;.',
'forum_avez_selectionne' => 'B&#7841;n &#273;&atilde; ch&#7885;n:',
'forum_cliquer_retour' => 'B&#7845;m <a href=\'@retour_forum@\'>v&ocirc; &#273;&acirc;y</a> &#273;&#7875; ti&#7871;p t&#7909;c.',
'forum_forum' => 'di&#7877;n &#273;&agrave;n',
'forum_info_modere' => 'Di&#7877;n &#273;&agrave;n n&agrave;y &#273;&#432;&#7907;c &#273;i&#7873;u h&#7907;p tr&#432;&#7899;c: b&agrave;i v&#7903; &#273;&oacute;ng g&oacute;p s&#7869; xu&#7845;t hi&#7879;n sau khi &#273;&#432;&#7907;c qu&#7843;n tr&#7883; vi&ecirc;n ch&#7845;p thu&#7853;n.',
'forum_lien_hyper' => '<b>&#272;i&#7875;m n&#7889;i hypertext</b> (kh&ocirc;ng b&#7855;t bu&#7897;c)',
'forum_message_definitif' => 'Th&#432; t&iacute;n &#273;&atilde; xong: g&#7917;i &#273;i',
'forum_message_trop_long' => 'Th&#432; t&iacute;n d&agrave;i qu&aacute;. &#272;&#7897; d&agrave;i t&#7889;i &#273;a 20000 m&#7851;u t&#7921;.',
'forum_ne_repondez_pas' => '&#272;&#7915;ng h&#7891;i &acirc;m email n&agrave;y, h&#7891;i &acirc;m trong di&#7877;n &#273;&agrave;n &#7903; &#273;&#7883;a ch&#7881; sau &#273;&acirc;y:',
'forum_non_inscrit' => 'Ho&#7863;c l&agrave; b&#7841;n ch&#432;a ghi danh, ho&#7863;c &#273;&#7883;a ch&#7881; hay m&#7853;t m&atilde; kh&ocirc;ng &#273;&uacute;ng.',
'forum_page_url' => '(N&#7871;u th&#432; t&iacute;n c&#7911;a b&#7841;n c&oacute; &#273;&#7873; c&#7853;p &#273;&#7871;n m&#7897;t b&agrave;i kh&aacute;c tr&ecirc;n web, xin &#273;i&#7873;n v&agrave;o t&#7921;a &#273;&#7873; v&agrave; &#273;&#7883;a ch&#7881; URL c&#7911;a n&oacute; d&#432;&#7899;i &#273;&acirc;y).',
'forum_par_auteur' => 'b&#7903;i @auteur@',
'forum_poste_par' => 'C&oacute; th&#432; t&iacute;n @parauteur@ &#273;i sau b&agrave;i c&#7911;a b&#7841;n.', # MODIF
'forum_probleme_database' => 'C&oacute; v&#7845;n &#273;&#7873; v&#7899;i database, th&#432; t&iacute;n c&#7911;a b&#7841;n kh&ocirc;ng l&#432;u tr&#7919; &#273;&#432;&#7907;c.',
'forum_qui_etes_vous' => '<b>Chi ti&#7871;t v&#7873; b&#7841;n</b> (kh&ocirc;ng b&#7855;t bu&#7897;c)',
'forum_texte' => 'Th&acirc;n b&agrave;i c&#7911;a th&#432; t&iacute;n:',
'forum_titre' => 'T&#7921;a &#273;&#7873;:',
'forum_titre_erreur' => 'C&oacute; l&#7895;i...',
'forum_url' => 'URL:',
'forum_valider' => 'X&aacute;c nh&#7853;n l&#7921;a ch&#7885;n n&agrave;y',
'forum_voir_avant' => 'Xem l&#7841;i th&#432; t&iacute;n tr&#432;&#7899;c khi &#273;&#259;ng',
'forum_votre_email' => '&#272;&#7883;a ch&#7881; email c&#7911;a b&#7841;n:',
'forum_votre_nom' => 'T&ecirc;n (hay b&iacute; danh):',
'forum_vous_enregistrer' => 'Tr&#432;&#7899;c khi tham gia v&agrave;o di&#7877;n &#273;&agrave;n n&agrave;y, b&#7841;n ph&#7843;i ghi danh. N&#7871;u ch&#432;a ghi danh, b&#7841;n ph&#7843;i',
'forum_vous_inscrire' => 'ghi danh.',

// I
'ical_texte_rss_articles' => 'H&#7891; s&#417; &laquo;backend&raquo; c&#7911;a c&aacute;c b&agrave;i tr&ecirc;n trang web n&agrave;y &#7903; &#273;&#7883;a ch&#7881;:',
'ical_texte_rss_articles2' => 'B&#7841;n c&#361;ng c&oacute; th&#7875; l&#7845;y h&#7891; s&#417; &laquo;backend&raquo; cho c&aacute;c b&agrave;i c&#7911;a t&#7915;ng &#273;&#7873; m&#7909;c:',
'ical_texte_rss_breves' => 'C&ograve;n c&oacute; m&#7897;t h&#7891; s&#417; cho c&aacute;c tin ng&#7855;n. N&#7871;u b&#7841;n th&ecirc;m s&#7889; &#273;&#7873; m&#7909;c, b&#7841;n ch&#7881; l&#7845;y d&#432;&#7907;c tin ng&#7855;n c&#7911;a &#273;&#7873; m&#7909;c n&agrave;y.',
'icone_a_suivre' => 'N&#417;i b&#7855;t &#273;&#7847;u',
'icone_admin_site' => 'Qu&#7843;n tr&#7883; website',
'icone_agenda' => 'Ch&#432;&#417;ng tr&igrave;nh ngh&#7883; s&#7921; v&agrave; th&#432; t&iacute;n',
'icone_aide_ligne' => 'Gi&uacute;p &#273;&#7905;',
'icone_articles' => 'B&agrave;i',
'icone_auteurs' => 'Ban bi&ecirc;n t&#7853;p',
'icone_breves' => 'Tin ng&#7855;n',
'icone_brouteur' => 'Xem l&#7865;',
'icone_configuration_site' => 'C&#7845;u h&igrave;nh',
'icone_configurer_site' => 'S&#7917;a c&#7845;u h&igrave;nh Website',
'icone_creer_nouvel_auteur' => 'Th&ecirc;m m&#7897;t t&aacute;c gi&#7843; m&#7899;i',
'icone_creer_rubrique' => 'Th&ecirc;m m&#7897;t &#273;&#7873; m&#7909;c m&#7899;i ',
'icone_creer_sous_rubrique' => 'Th&ecirc;m m&#7897;t &#273;&#7873; m&#7909;c ph&#7909;',
'icone_deconnecter' => 'R&#7901;i kh&#7887;i',
'icone_discussions' => 'Th&#7843;o lu&#7853;n',
'icone_doc_rubrique' => 'T&agrave;i li&#7879;u c&#7911;a &#273;&#7873; m&#7909;c',
'icone_ecrire_article' => 'Vi&#7871;t m&#7897;t b&agrave;i m&#7899;i',
'icone_edition_site' => 'S&#7917;a &#273;&#7893;i',
'icone_forum_administrateur' => 'Di&#7877;n &#273;&agrave;n qu&#7843;n tr&#7883; vi&ecirc;n',
'icone_forum_suivi' => 'Qu&#7843;n tr&#7883; di&#7877;n &#273;&agrave;n',
'icone_gestion_langues' => 'Qu&#7843;n tr&#7883; ng&ocirc;n ng&#7919;',
'icone_informations_personnelles' => 'D&#7919; ki&#7879;n c&aacute; nh&acirc;n',
'icone_interface_complet' => 'Xem t&#7845;t c&#7843;',
'icone_interface_simple' => 'Xem &#273;&#417;n gi&#7843;n',
'icone_maintenance_site' => 'B&#7843;o tr&igrave;',
'icone_messagerie_personnelle' => 'Th&#432; t&iacute;n c&aacute; nh&acirc;n',
'icone_mots_cles' => 'T&#7915; then ch&#7889;t',
'icone_nouvelle_breve' => 'Vi&#7871;t m&#7897;t tin ng&#7855;n m&#7899;i',
'icone_repartition_actuelle' => 'Cho xem ph&acirc;n lo&#7841;i hi&#7879;n nay',
'icone_repartition_debut' => 'Cho xem ph&acirc;n lo&#7841;i t&#7915; ban &#273;&#7847;u',
'icone_repartition_visites' => 'Ph&acirc;n b&#7889; s&#7889; th&#259;m vi&#7871;ng',
'icone_rubriques' => '&ETH;&#7873; M&#7909;c',
'icone_sauver_site' => 'L&#432;u tr&#7919; database',
'icone_site_entier' => 'T&#7845;t c&#7843; b&agrave;i trong website ',
'icone_sites_references' => 'Li&ecirc;n k&#7871;t',
'icone_statistiques' => 'Th&#7889;ng k&ecirc; t&#7893;ng qu&aacute;t',
'icone_statistiques_visites' => 'Th&#7889;ng k&ecirc;',
'icone_suivi_activite' => 'Nh&#7919;ng vi&#7879;c c&#7911;a Ban Bi&ecirc;n T&#7853;p',
'icone_suivi_actualite' => 'Ti&#7871;n tri&#7875;n c&#7911;a trang web',
'icone_suivi_forums' => 'Qu&#7843;n tr&#7883; di&#7877;n &#273;&agrave;n',
'icone_suivi_pettions' => 'Qu&#7843;n tr&#7883; th&#7881;nh nguy&#7879;n th&#432;',
'icone_suivi_revisions' => 'C&#7853;p nh&#7853;t b&agrave;i v&#7903;',
'icone_supprimer_document' => 'X&oacute;a t&agrave;i li&#7879;u n&agrave;y',
'icone_supprimer_image' => 'X&oacute;a h&igrave;nh n&agrave;y',
'icone_supprimer_message' => 'Xo&aacute; th&#432; t&iacute;n n&agrave;y',
'icone_tous_articles' => 'T&#7845;t c&#7843; b&agrave;i v&#7903; c&#7911;a b&#7841;n',
'icone_tous_auteur' => 'C&aacute;c t&aacute;c gi&#7843;',
'icone_valider_message' => 'Ch&#7845;p thu&#7853;n',
'icone_visiter_site' => 'Tr&#7903; v&#7873; trang nh&agrave;',
'icone_voir_en_ligne' => 'Xem online',
'image_tourner_180' => 'Xoay 180&deg;',
'image_tourner_droite' => 'Xoay qua ph&#7843;i 90&deg;',
'image_tourner_gauche' => 'Xoay qua tr&aacute;i 90&deg;',
'img_indisponible' => 'h&igrave;nh kh&ocirc;ng c&oacute;',
'impossible' => 'kh&ocirc;ng th&#7875; &#273;&#432;&#7907;c',
'info_a_suivre' => 'N&#416;I B&#7854;T &#272;&#7846;U&raquo;',
'info_a_valider' => '[ch&#7901; th&ocirc;ng qua]',
'info_acces_interdit' => 'Kh&ocirc;ng v&agrave;o/d&ugrave;ng &#273;&#432;&#7907;c',
'info_acces_refuse' => 'Kh&ocirc;ng v&agrave;o &#273;&#432;&#7907;c',
'info_action' => 'C&ocirc;ng vi&#7879;c: @action@',
'info_administrer_rubriques' => 'B&#7841;n c&oacute; th&#7875; qu&#7843;n tr&#7883; &#273;&#7873; m&#7909;c n&agrave;y v&agrave; c&aacute;c &#273;&#7873; m&#7909;c ph&#7909;',
'info_adresse_non_indiquee' => 'B&#7841;n kh&ocirc;ng cho &#273;&#7883;a ch&#7881; &#273;&#7875; th&#7917; nghi&#7879;m!',
'info_aide' => 'GI&Uacute;P &#272;&#7904;:',
'info_ajouter_mot' => 'Th&ecirc;m t&#7915; then ch&#7889;t n&agrave;y',
'info_annonce' => 'TH&Ocirc;NG B&Aacute;O',
'info_annonces_generales' => 'Th&ocirc;ng tin t&#7893;ng qu&aacute;t:',
'info_article_propose' => 'B&agrave;i &#273;&atilde; n&#7897;p',
'info_article_publie' => 'B&agrave;i &#273;&atilde; ph&aacute;t h&agrave;nh',
'info_article_redaction' => 'B&agrave;i &#273;ang so&#7841;n',
'info_article_refuse' => 'B&agrave;i b&#7883; t&#7915; ch&#7889;i',
'info_article_supprime' => 'B&agrave;i &#273;&atilde; x&oacute;a',
'info_articles' => 'B&agrave;i',
'info_articles_a_valider' => 'Nh&#7919;ng b&agrave;i ch&#7901; th&ocirc;ng qua',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'B&agrave;i v&#7903; &#273;&atilde; n&#7897;p',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 't&aacute;c gi&#7843;:',
'info_authentification_ftp' => 'X&aacute;c nh&#7853;n (d&ugrave;ng FTP).',
'info_bloquer_lien' => 'ch&#7863;n &#273;i&#7875;m n&#7889;i n&agrave;y',
'info_breves_02' => 'Tin ng&#7855;n',
'info_breves_2' => 'tin ng&#7855;n',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Nh&#7919;ng tin ng&#7855;n ch&#7901; th&ocirc;ng qua',
'info_connexion_refusee' => 'Kh&ocirc;ng n&#7889;i v&agrave;o &#273;&#432;&#7907;c',
'info_contact_developpeur' => 'Xin li&ecirc;n l&#7841;c v&#7899;i l&#7853;p tr&igrave;nh vi&ecirc;n.',
'info_contenance' => 'Website c&oacute;:',
'info_contribution' => 'th&#432; t&iacute;n c&#7911;a di&#7877;n &#273;&agrave;n',
'info_copyright' => '@spip@ l&agrave; nhu li&#7879;u mi&#7877;n ph&iacute; ph&#7893; bi&#7871;n @lien_gpl@.',
'info_copyright_doc' => '&#272;&#7875; bi&#7871;t th&ecirc;m, xin v&agrave;o xem trang <a href="@spipnet@">http://www.spip.net/vi</a>.', # MODIF
'info_copyright_gpl' => 'theo gi&#7845;p ph&eacute;p GPL',
'info_cours_edition' => 'B&agrave;i c&#7911;a b&#7841;n &#273;ang so&#7841;n',
'info_creer_repertoire' => 'Xin l&#7853;p ra m&#7897;t h&#7891; s&#417; hay m&#7897;t ng&#259;n mang t&ecirc;n:',
'info_creer_repertoire_2' => 'trong ng&#259;n ph&#7909; <b>@repertoire@</b>, k&#7871; &#273;&#243;', # MODIF
'info_creer_vignette' => 't&#7921; &#273;&#7897;ng t&#7841;o ra c&aacute;c h&igrave;nh m&#7851;u nh&#7887;',
'info_deplier' => 'M&#7903; ra',
'info_descriptif_nombre' => 'M&ocirc; t&#7843;:',
'info_description' => 'T&oacute;m l&#432;&#7907;c:',
'info_description_2' => 'T&oacute;m l&#432;&#7907;c:',
'info_dimension' => 'Kh&#7893;:',
'info_document' => 'T&agrave;i li&#7879;u ',
'info_document_indisponible' => 'T&agrave;i li&#7879;u n&agrave;y kh&ocirc;ng c&oacute;',
'info_documents' => 'T&agrave;i li&#7879;u',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP cho ph&eacute;p trao &#273;&#7893;i th&#432; t&iacute;n v&agrave; l&#7853;p ra nh&#7919;ng di&#7877;n &#273;&agrave;n trao &#273;&#7893;i ri&ecirc;ng gi&#7919;a c&aacute;c tham d&#7921; vi&ecirc;n. B&#7841;n c&oacute; th&#7875; t&#7855;t/m&#7903; &#273;&#7863;c &#273;i&#7875;m n&agrave;y.',
'info_ecire_message_prive' => 'Vi&#7871;t th&#432; t&iacute;n ri&ecirc;ng',
'info_email_invalide' => '&#272;&#7883;a ch&#7881; email kh&ocirc;ng &#273;&uacute;ng.',
'info_en_cours_validation' => 'B&agrave;i vi&#7871;t &#273;ang so&#7841;n',
'info_en_ligne' => '&#272;ang online:',
'info_envoyer_message_prive' => 'G&#7917;i th&#432; ri&ecirc;ng cho t&aacute;c gi&#7843; n&agrave;y',
'info_erreur_requete' => 'V&#7845;n &#273;&aacute;p c&oacute; l&#7895;i: ',
'info_erreur_squelette2' => 'Kh&ocirc;ng c&oacute; m&#7851;u cho trang web n&agrave;y. Kh&ocirc;ng t&igrave;m thay h&#7891; s&#417; <b>@fichier@</b>...',
'info_erreur_systeme' => 'Th&ocirc;ng b&aacute;o l&#7895;i s&#7889; (errno @errsys@)',
'info_erreur_systeme2' => '&#272;&#297;a c&#7913;ng c&oacute; th&#7875; &#273;&atilde; &#273;&#7847;y hay l&agrave; database b&#7883; h&#432;. <br />
 <font color=\'red\'>Xin <a href=\'@script@\'>s&#7917;a Database</a>,
 hay li&ecirc;n l&#7841;c v&#7899;i qu&#7843;n tr&#7883; vi&ecirc;n m&aacute;y.</font>', # MODIF
'info_fini' => 'Xong r&#7891;i! ',
'info_format_image' => 'D&#7841;ng h&igrave;nh d&ugrave;ng &#273;&#7875; l&#7853;p ra h&igrave;nh m&#7851;u: @gd_formats@.',
'info_format_non_defini' => 'D&#7841;ng kh&ocirc;ng &#273;&#7883;nh r&otilde;',
'info_grand_ecran' => 'Xem d&#7841;ng l&#7899;n',
'info_image_aide' => 'GI&Uacute;P &#272;&#7904;',
'info_image_process_titre' => 'C&aacute;ch t&#7841;o h&igrave;nh m&#7851;u nh&#7887;',
'info_impossible_lire_page' => '<b>L&#7895;i!</b> Kh&#244;ng &#273;&#7885;c &#273;&#432;&#7907;c trang <tt><html>@test_proxy@</html></tt> qua proxy <tt>', # MODIF
'info_inclusion_directe' => 'G&#7897;p v&agrave;o tr&#7921;c ti&#7871;p:',
'info_inclusion_vignette' => 'G&#7897;p c&aacute;c h&igrave;nh nh&#7887; xem tr&#432;&#7899;c:',
'info_installation_systeme_publication' => 'Thi&#7871;t tr&iacute; h&#7879; th&#7889;ng ph&aacute;t h&agrave;nh ...',
'info_installer_documents' => 'B&#7841;n c&#243; th&#7875; c&#224;i &#273;&#7863;t t&#7845;t c&#7843; t&#224;i li&#7879;u trong ng&#259;n @upload@.', # MODIF
'info_installer_ftp' => 'L&#224; qu&#7843;n tr&#7883; vi&#234;n, b&#7841;n c&#243; th&#7875; c&#224;i &#273;&#7863;t (d&#249;ng FTP) c&#225;c h&#7891; s&#417; trong ng&#259;n @upload@ r&#7891;i ch&#7885;n l&#7921;a ch&#250;ng sau &#273;&#243; tr&#7921;c ti&#7871;p t&#7915; &#273;&#226;y.', # MODIF
'info_installer_images' => 'B&#7841;n c&oacute; th&#7875; c&agrave;i &#273;&#7863;t h&igrave;nh trong d&#7841;ng JPEG, GIF v&agrave; PNG.',
'info_installer_images_dossier' => 'C&agrave;i &#273;&#7841;t h&igrave;nh trong ng&#259;n @upload@ &#273;&#7875; c&oacute; th&#7875; ch&#7885;n l&#7921;a ch&uacute;ng t&#7915; &#273;&acirc;y.',
'info_installer_tous_documents' => 'C&agrave;i &#273;&#7863;t t&#7845;t c&#7843; t&agrave;i li&#7879;u',
'info_interface_complete' => 'Xem t&#7845;t c&#7843;',
'info_interface_simple' => 'Xem &#273;&#417;n gi&#7843;n',
'info_joindre_document_article' => 'B&#7841;n c&oacute; th&#7875; &#273;&iacute;nh k&egrave;m v&agrave;o b&agrave;i vi&#7871;t c&aacute;c h&#7891; s&#417; trong d&#7841;ng',
'info_joindre_document_rubrique' => 'B&#7841;n c&oacute; th&#7875; th&ecirc;m v&agrave;o &#273;&#7873; m&#7909;c n&agrave;y c&aacute;c h&#7891; s&#417; trong d&#7841;ng',
'info_joindre_documents_article' => ' B&#7841;n c&oacute; th&#7875; &#273;&iacute;nh k&egrave;m v&agrave;o b&agrave;i vi&#7871;t c&aacute;c h&#7891; s&#417; trong d&#7841;ng: ',
'info_l_article' => 'b&agrave;i',
'info_la_breve' => 'tin ng&#7855;n',
'info_la_rubrique' => '&#273;&#7873; m&#7909;c',
'info_langue_principale' => 'Ng&ocirc;n ng&#7919; c&#7911;a website',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ ch&#7845;m',
'info_les_auteurs_1' => 'c&#7911;a @les_auteurs@ ',
'info_logo_format_interdit' => 'Ch&#7881; ch&#7845;p nh&#7853;n logo trong c&aacute;c d&#7841;ng @formats@.',
'info_logo_max_poids' => 'Logo ph&#7843;i nh&#7887; h&#417;n @maxi@ (H&#7891; s&#417; n&agrave;y l&agrave; @actuel@).',
'info_logo_max_taille' => 'H&#7891; s&#417; n&agrave;y ph&#7843;i nh&#7887; h&#417;n @maxi@ (h&#7891; s&#417; n&agrave;y l&agrave; @actuel@).',
'info_mail_fournisseur' => ' you@isp.com',
'info_message_2' => 'TH&#431; T&Iacute;N',
'info_message_supprime' => 'TH&#431; T&Iacute;N &#272;&#431;&#7906;C X&Oacute;A',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Ng&agrave;y &#273;&#259;ng t&#7843;i online:',
'info_modification_parametres_securite' => 'S&#7917;a &#273;&#7893;i c&aacute;c th&ocirc;ng s&#7889; an ninh',
'info_mois_courant' => 'Trong th&aacute;ng:',
'info_mot_cle_ajoute' => 'T&#7915; then ch&#7889;t sau &#273;&#432;&#7907;c th&ecirc;m v&agrave;o ',
'info_multi_herit' => 'Ng&ocirc;n ng&#7919; &#273;&#7883;nh s&#7861;n',
'info_multi_langues_soulignees' => '<u>C&aacute;c ng&ocirc;n ng&#7919; c&oacute; g&#7841;ch d&#432;&#7899;i</u> c&oacute; ngh&#297;a l&agrave; ph&#7847;n v&#259;n b&#7843;n c&#7911;a giao di&#7879;n &#273;&#432;&#7907;c d&#7883;ch qua ng&ocirc;n ng&#7919; &#273;&oacute;. N&#7871;u b&#7841;n ch&#7885;n m&#7897;t ng&ocirc;n ng&#7919; &#273;&oacute;, c&aacute;c ph&#7847;n v&#259;n b&#7843;n (ng&agrave;y th&aacute;ng, m&#7851;u &#273;&#417;n) s&#7869; &#273;&#432;&#7907;c t&#7921; &#273;&#7897;ng d&#7883;ch qua. C&ograve;n nh&#7919;ng ng&ocirc;n ng&#7919; kh&ocirc;ng c&oacute; h&agrave;ng g&#7841;ch d&#432;&#7899;i th&igrave; kh&ocirc;ng c&oacute; b&#7843;n d&#7883;ch. Ph&#7847;n giao di&#7879;n s&#7869; hi&#7879;n ra b&#7857;ng ng&ocirc;n ng&#7919; ch&iacute;nh c&#7911;a trang web.', # MODIF
'info_multilinguisme' => 'D&#7909;ng nhi&#7873;u th&#7913; ti&#7871;ng',
'info_nom_non_utilisateurs_connectes' => 'T&ecirc;n b&#7841;n kh&ocirc;ng th&#7845;y c&oacute; trong danh s&aacute;ch nh&#7919;ng ng&#432;&#7901;i d&ugrave;ng &#273;ang n&#7889;i v&agrave;o.',
'info_nom_utilisateurs_connectes' => 'T&ecirc;n b&#7841;n c&oacute; trong danh s&aacute;ch nh&#7919;ng ng&#432;&#7901;i d&ugrave;ng &#273;ang n&#7889;i v&agrave;o.',
'info_nombre_en_ligne' => 'Online b&acirc;y gi&#7901;:',
'info_non_resultat' => 'Kh&ocirc;ng c&oacute; k&#7871;t qu&#7843; cho "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'B&#7841;n kh&ocirc;ng d&ugrave;ng ph&#432;&#417;ng ti&#7879;n th&#432; t&iacute;n n&#7897; b&#7897; c&#7911;a website n&agrave;y.',
'info_nouveau_message' => 'C&Oacute; TH&#431; T&Iacute;N M&#7898;I',
'info_nouveaux_messages' => 'B&#7840;N C&Oacute; @total_messages@ TH&#431; T&Iacute;N M&#7898;I',
'info_numero_abbreviation' => 'S&#7889;&nbsp;',
'info_obligatoire' => 'Cette information est obligatoire', # NEW
'info_panne_site_syndique' => 'Website syndicated b&#7883; v&#7845;n &#273;&#7873;',
'info_pense_bete' => 'GHI NH&#7898;',
'info_petit_ecran' => 'Xem d&#7841;ng nh&#7887;',
'info_petition_close' => 'P&eacute;tition close', # NEW
'info_pixels' => 'ch&#7845;m',
'info_plusieurs_mots_trouves' => 'T&igrave;m th&#7845;y m&#7897;t s&#7889; t&#7915; then ch&#7889;t cho "@cherche_mot@":',
'info_popularite_5' => ' ph&#7893; th&ocirc;ng:',
'info_portfolio' => 'T&#7853;p h&#7891; s&#417;',
'info_portfolio_automatique' => 'Portfolio t&#7921; &#273;&#7897;ng:',
'info_premier_resultat' => '[@debut_limit@ k&#7871;t qu&#7843; &#273;&#7847;u ti&ecirc;n trong s&#7889; @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ k&#7871;t qu&#7843; &#273;&#7847;u ti&ecirc;n trong s&#7889; @total@]',
'info_probleme_grave' => 'l&#7895;i c&#7911;a',
'info_propose_1' => '[@nom_site_spip@] N&#7897;p: @titre@',
'info_propose_2' => 'B&agrave;i &#273;&#432;&#7907;c n&#7897;p
-----------------',
'info_propose_3' => 'B&agrave;i "@titre@" &#273;&#432;&#7907;c n&#7897;p &#273;&#7875; ph&aacute;t h&agrave;nh.',
'info_propose_4' => 'B&#7841;n n&ecirc;n xem l&#7841;i v&agrave; cho bi&#7871;t &yacute; ki&#7871;n',
'info_propose_5' => 'trong di&#7877;n &#273;&agrave;n li&ecirc;n h&#7879;. Qua &#273;&#7883;a ch&#7881;:',
'info_publie_01' => 'B&agrave;i "@titre@" &#273;&#432;&#7907;c ch&#7845;p thu&#7853;n b&#7903;i @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] &#272;&#258;NG T&#7842;I: @titre@',
'info_publie_2' => 'B&agrave;i &#273;&#432;&#7907;c &#273;&#259;ng t&#7843;i
-----------------',
'info_rechercher' => 'T&igrave;m ki&#7871;m',
'info_rechercher_02' => 'T&igrave;m:',
'info_remplacer_vignette' => 'Thay th&#7871; h&igrave;nh xem tr&#432;&#7899;c &#273;&#7883;nh s&#7861;n b&#7857;ng logo ri&ecirc;ng:',
'info_retablir_lien' => 'Ph&#7909;c h&#7891;i &#273;i&#7875;m n&#7889;i k&#7871;t n&agrave;y',
'info_retirer_mot' => 'X&oacute;a t&#7915; then ch&#7889;t n&agrave;y',
'info_retirer_mots' => 'X&oacute;a h&#7871;t t&#7845;t c&#7843; t&#7915; then ch&#7889;t',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'kh&ocirc;ng t&#7921;a &#273;&#7873;',
'info_selectionner_fichier' => 'B&#7841;n c&#243; th&#7875; ch&#7885;n m&#7897;t h&#7891; tr&#417; trong ng&#259;n @upload@', # MODIF
'info_selectionner_fichier_2' => 'Ch&#7885;n m&#7897;t h&#7891; s&#417;:',
'info_signature_supprimee' => 'Ch&#7919; k&yacute; &#273;&atilde; &#273;&#432;&#7907;c xo&aacute;',
'info_signature_supprimee_erreur' => 'L&#7895;i: code &#273;&#7875; xo&aacute; n&agrave;y kh&ocirc;ng li&ecirc;n h&#7879; &#273;&#7871;n b&#7845;t k&#7923; ch&#7919; k&yacute; n&agrave;o',
'info_site_attente' => 'Ch&#7901; ch&#7845;p thu&#7853;n website',
'info_site_reference' => 'Website n&#7889;i k&#7871;t online',
'info_site_refuse' => 'Website b&#7883; t&#7915; ch&#7889;i',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'N&#7889;i k&#7871;t m&#7897;t website',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'x&oacute;a h&igrave;nh nh&#7887; xem tr&#432;&#7899;c',
'info_symbole_bleu' => 'K&yacute; hi&#7879;u <b>xanh d&#432;&#417;ng</b> cho bi&#7871;t <b>b&#7843;n ghi nh&#7899;</b>: t&#7913;c l&agrave; th&#432; t&iacute;n cho ri&ecirc;ng b&#7841;n.', # MODIF
'info_symbole_jaune' => 'K&#253; hi&#7879;u <b>v&#224;ng</b> cho bi&#7871;t <b>th&#244;ng b&#225;o &#273;&#7871;n t&#7845;t c&#7843; ch&#7911; b&#250;t</b>: t&#7845;t c&#7843; ch&#7911; b&#250;t c&#243; th&#7875; s&#7917;a &#273;&#7893;i &#273;&#432;&#7907;c, v&#224; ch&#7911; b&#250;t n&#224;o c&#361;ng nh&#236;n th&#7845;y &#273;&#432;&#7907;c.', # MODIF
'info_symbole_vert' => 'K&yacute; hi&#7879;u <b>xanh l&aacute; c&acirc;y</b> cho bi&#7871;t <b>th&#432; t&iacute;n trao &#273;&#7893;i v&#7899;i nh&#7919;ng ng&#432;&#7901;i d&ugrave;ng</b> c&#7911;a website.', # MODIF
'info_syndication' => 'ph&aacute;t h&agrave;nh:',
'info_syndication_articles' => 'b&agrave;i',
'info_telecharger' => '&#272;em/t&#7843;i l&ecirc;n t&#7915; m&aacute;y b&#7841;n:',
'info_telecharger_nouveau_logo' => '&#272;em/t&#7843;i l&ecirc;n m&#7897;t logo m&#7899;i:',
'info_telecharger_ordinateur' => '&#272;em/t&#7843;i l&ecirc;n t&#7915; m&aacute;y b&#7841;n:',
'info_tous_resultats_enregistres' => '[To&agrave;n b&#7897; k&#7871;t qu&#7843; &#273;&#432;&#7907;c ghi nh&#7899; l&#7841;i] ',
'info_tout_afficher' => 'Xem t&#7845;t c&#7843;',
'info_travaux_texte' => 'Website n&agrave;y ch&#432;a &#273;&#432;&#7907;c ho&agrave;n t&#7845;t. Xin qu&yacute; v&#7883; tr&#7903; l&#7841;i trong v&agrave;i ng&agrave;y sau.',
'info_travaux_titre' => 'Website &#273;ang &#273;&#432;&#7907;c x&acirc;y d&#7921;ng',
'info_trop_resultat' => 'Qu&aacute; nhi&#7873;u k&#7871;t qu&#7843; cho "@cherche_mot@"; xin l&#7885;c l&#7921;a l&#7841;i vi&#7879;c t&igrave;m ki&#7871;m.',
'info_utilisation_messagerie_interne' => 'B&#7841;n &#273;ang d&ugrave;ng ph&#432;&#417;ng ti&#7879;n th&#432; t&iacute;n n&#7897;i b&#7897; c&#7911;a website. ',
'info_valider_lien' => 'ch&#7845;p thu&#7853;n &#273;i&#7875;m n&#7889;i k&#7871;t n&agrave;y',
'info_verifier_image' => ', xin ki&#7875;m l&#7841;i xem h&igrave;nh b&#7841;n chuy&#7875;n t&#7843;i c&oacute; &#273;&uacute;ng kh&ocirc;ng.',
'info_vignette_defaut' => 'H&igrave;nh xem tr&#432;&#7899;c &#273;&#7883;nh s&#7861;n',
'info_vignette_personnalisee' => 'H&igrave;nh xem tr&#432;&#7899;c c&oacute; &#273;i&#7873;u ch&#7881;nh',
'info_visite' => 'th&#259;m vi&#7871;ng:',
'info_visites' => ' th&#259;m vi&#7871;ng:',
'info_vos_rendez_vous' => 'Nh&#7919;ng l&#7847;n h&#7865;n s&#7855;p t&#7899;i',
'info_zoom' => 'ph&oacute;ng l&#7899;n',
'infos_vos_pense_bete' => 'B&#7843;n ghi nh&#7899; c&#7911;a b&#7841;n', # MODIF
'item_breve_proposee' => 'N&#7897;p v&agrave;o',

// L
'lien_afficher_icones_seuls' => 'Xem icon m&agrave; th&ocirc;i',
'lien_afficher_texte_icones' => 'Xem icon v&agrave; ch&#7919;',
'lien_afficher_texte_seul' => 'Xem ch&#7919; m&agrave; th&ocirc;i',
'lien_liberer' => 'ph&#7893; bi&#7871;n',
'lien_liberer_tous' => 'G&#7905; b&#7887; nh&#7919;ng b&agrave;i n&agrave;y',
'lien_nouvea_pense_bete' => 'GHI NH&#7898; M&#7898;I',
'lien_nouveau_message' => 'TH&#431; T&Iacute;N M&#7898;I',
'lien_nouvelle_annonce' => 'TH&Ocirc;NG B&Aacute;O M&#7898;I',
'lien_petitions' => 'TH&#7880;NH NGUY&#7878;N TH&#431;',
'lien_popularite' => 'ph&#7893; th&ocirc;ng: @popularite@%',
'lien_racine_site' => 'G&#7888;C WEBSITE',
'lien_reessayer' => 'th&#7917; lai l&#7847;n n&#7919;a',
'lien_repondre_message' => 'H&#7891;i &acirc;m th&#432; t&iacute;n n&agrave;y',
'lien_supprimer' => 'x&oacute;a',
'lien_tout_afficher' => 'Hi&#7875;n th&#7883; t&#7845;t c&#7843;',
'lien_visite_site' => 'V&agrave;o trang web n&agrave;y',
'lien_visites' => '@visites@ l&#7847;n t&#7899;i xem',
'lien_voir_auteur' => 'Xem t&aacute;c gi&#7843;',
'ligne' => 'D&ograve;ng',
'login' => '&#272;&#432;&#7901;ng n&#7889;i',
'login_acces_prive' => 'v&agrave;o v&ugrave;ng ri&ecirc;ng',
'login_autre_identifiant' => 'n&#7889;i v&#7899;i t&ecirc;n g&#7885;i (ID) kh&aacute;c',
'login_cookie_accepte' => '&#272;i&#7873;u ch&#7881;nh browser &#273;&#7875; ch&#7845;p nh&#7853;n ch&uacute;ng (&iacute;t nh&#7845;t l&agrave; cho website n&agrave;y).',
'login_cookie_oblige' => '&#272;&#7875; nh&#7853;n di&#7879;n b&#7841;n cho ch&#7855;c, b&#7841;n ph&#7843;i ch&#7845;p nh&#7853;n m&#7903; cookies l&ecirc;n.',
'login_deconnexion_ok' => 'Ra kh&#7887;i.',
'login_erreur_pass' => 'C&oacute; l&#7895;i m&#7853;t m&atilde;.',
'login_espace_prive' => 'v&ugrave;ng ri&ecirc;ng',
'login_identifiant_inconnu' => 'Kh&ocirc;ng bi&#7871;t danh t&aacute;nh "@login@".',
'login_login' => 'Login:',
'login_login2' => 'Login (danh t&aacute;nh &#273;&#7875; v&agrave;o trang web):',
'login_login_pass_incorrect' => '(login ho&#7863;c m&#7853;t m&atilde; kh&ocirc;ng &#273;&uacute;ng).',
'login_motpasseoublie' => 'qu&ecirc;n m&#7853;t m&atilde;?',
'login_non_securise' => 'C&#7843;nh b&aacute;o, phi&#7871;u &#273;i&#7873;n n&agrave;y kh&ocirc;ng an to&agrave;n.
 N&#7871;u b&#7841;n kh&ocirc;ng mu&#7889;n m&#7853;t m&atilde; b&#7883; ch&#7863;n l&#7845;y tr&ecirc;n net,
 xin m&#7903; Javascript trong browser l&ecirc;n v&agrave;',
'login_nouvelle_tentative' => 'Th&#7917; l&#7841;i',
'login_par_ici' => 'B&#7841;n &#273;&#432;&#7907;c ghi danh ... l&#7889;i n&agrave;y ...',
'login_pass2' => 'M&#7853;t m&atilde;:',
'login_preferez_refuser' => '<b>N&#7871;u b&#7841;n ch&#7885;n kh&ocirc;ng m&#7903; cookies l&ecirc;n</b>, c&oacute; m&#7897;t c&aacute;ch kh&aacute;c &#273;&#7875; v&agrave;o (kh&ocirc;ng an to&agrave;n b&#7857;ng):',
'login_recharger' => 'n&#7841;p l&#7841;i trang n&agrave;y',
'login_rester_identifie' => 'V&#7851;n c&ograve;n nh&#7899; trong v&ograve;ng v&agrave;i ng&agrave;y',
'login_retour_public' => 'Tr&#7903; l&#7841;i trang web c&ocirc;ng c&#7897;ng',
'login_retour_site' => 'Tr&#7903; l&#7841;i trang web c&ocirc;ng c&#7897;ng',
'login_retoursitepublic' => 'tr&#7903; l&#7841;i trang web c&ocirc;ng c&#7897;ng',
'login_sans_cookiie' => 'Nh&#7853;n di&#7879;n kh&ocirc;ng c&#7847;n cookie',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 'ghi danh',
'login_test_navigateur' => 'th&#7917; browser/n&#7889;i l&#7841;i',
'login_verifiez_navigateur' => '(Tuy nhi&ecirc;n, ki&#7875;m l&#7841;i &#273;&#7875; bi&#7871;t l&agrave; browser kh&ocirc;ng c&oacute; nh&#7899; m&#7853;t m&atilde; c&#7911;a b&#7841;n...)',

// M
'masquer_colonne' => 'Masquer cette colonne', # NEW
'masquer_trad' => 'd&#7845;u c&aacute;c b&#7843;n d&#7883;ch',
'module_fichiers_langues' => 'H&#7891; s&#417; ng&ocirc;n ng&#7919;',

// N
'navigateur_pas_redirige' => 'N&#7871;u browser c&#7911;a b&#7841;n kh&ocirc;ng &#273;&#432;&#7907;c h&#432;&#7899;ng qua m&#7897;t &#273;&#7883;a ch&#7881; URL m&#7899;i, xin b&#7845;m v&ocirc; &#273;&acirc;y &#273;&#7875; ti&#7871;p t&#7909;c.',
'numero' => 'S&#7889;',

// O
'occurence' => 'L&#7847;n',
'onglet_affacer_base' => 'X&oacute;a b&#7887; database',
'onglet_auteur' => 'T&aacute;c gi&#7843;',
'onglet_contenu_site' => '&#272;&#7863;c &#273;i&#7875;m c&#259;n b&#7843;n',
'onglet_evolution_visite_mod' => 'Ti&#7871;n tr&igrave;nh',
'onglet_fonctions_avances' => '&#272;&#7863;c &#273;i&#7875;m ph&#7909; tr&#7897;i',
'onglet_informations_personnelles' => 'D&#7919; ki&#7879;n c&aacute; nh&acirc;n',
'onglet_interactivite' => '&#272;&#7863;c &#273;i&#7875;m th&ocirc;ng tin',
'onglet_messagerie' => 'Th&#432; t&iacute;n',
'onglet_messages_internes' => 'Th&#432; t&iacute;n n&#7897;i b&#7897;',
'onglet_messages_publics' => 'Th&#432; t&iacute;n c&ocirc;ng c&#7897;ng',
'onglet_messages_vide' => 'Th&#432; t&iacute;n kh&ocirc;ng l&#7901;i',
'onglet_origine_visites' => 'Xu&#7845;t x&#7913; c&#7911;a th&#259;m vi&#7871;ng',
'onglet_repartition_debut' => 't&#7915; ban &#273;&#7847;u',
'onglet_repartition_lang' => 'Ph&#7893; bi&#7871;n theo ng&ocirc;n ng&#7919;',
'onglet_repartition_rubrique' => 'Ph&acirc;n lo&#7841;i theo &#273;&#7873; m&#7909;c',
'onglet_save_restaur_base' => 'L&#432;u tr&#7919;/ph&#7909;c h&#7891;i database',
'onglet_vider_cache' => 'D&#7885;n s&#7841;ch cache',

// P
'pass_choix_pass' => 'Xin ch&#7885;n m&#7853;t m&atilde; m&#7899;i:',
'pass_erreur' => 'C&oacute; l&#7895;i',
'pass_erreur_acces_refuse' => '<b>L&#7895;i:</b> b&#7841;n kh&ocirc;ng c&oacute; quy&#7873;n h&#7841;n v&agrave;o website n&agrave;y n&#7919;a.',
'pass_erreur_code_inconnu' => '<b>L&#7895;i:</b> m&atilde; s&#7889; n&agrave;y kh&ocirc;ng tr&ugrave;ng h&#7907;p v&#7899;i nh&#7919;ng nh&acirc;n s&#7921; &#273;&#432;&#7907;c ph&eacute;p v&agrave;o website n&agrave;y.',
'pass_erreur_non_enregistre' => '<b>L&#7895;i:</b> &#272;&#7883;a ch&#7881; <tt>@email_oubli@</tt> ch&#432;a c&oacute; ghi danh v&#7899;i website.',
'pass_erreur_non_valide' => '<b>L&#7895;i:</b> Email <tt>@email_oubli@</tt> kh&ocirc;ng &#273;&uacute;ng!',
'pass_erreur_probleme_technique' => '<b>L&#7895;i:</b> Kh&ocirc;ng g&#7917;i email &#273;i &#273;&#432;&#7907;c v&igrave; tr&#7909;c tr&#7863;c k&#7929; thu&#7853;t.',
'pass_espace_prive_bla' => 'Kh&aacute;ch th&#259;m vi&#7871;ng ch&#7881; v&agrave;o &#273;&#432;&#7907;c v&ugrave;ng ri&ecirc;ng sau khi ghi danh. Ghi danh r&#7891;i, b&#7841;n c&oacute; th&#7875; xem c&aacute;c b&agrave;i v&#7903; &#273;ang so&#7841;n, n&#7897;p b&agrave;i v&agrave;o v&agrave; tham gia v&agrave;o c&aacute;c di&#7877;n &#273;&agrave;n.',
'pass_forum_bla' => 'Di&#7877;n &#273;&agrave;n b&#7841;n mu&#7889;n v&agrave;o ch&#7881; d&agrave;nh ri&ecirc;ng cho c&aacute;c v&#7883; kh&aacute;ch c&oacute; ghi danh.',
'pass_indiquez_cidessous' => '&#272;&aacute;nh v&agrave;o &#273;&#7883;a ch&#7881; email m&agrave; b&#7841;n &#273;&atilde; d&ugrave;ng ghi danh tr&#432;&#7899;c &#273;&acirc;y. Sau &#273;&oacute;, b&#7841;n s&#7869; nh&#7853;n qua email chi ti&#7871;t ch&#7881; d&#7851;n c&aacute;ch t&igrave;m l&#7841;i ph&eacute;p ra/v&ocirc;.',
'pass_mail_passcookie' => '(&#273;&acirc;y l&agrave; th&#432; t&iacute;n t&#7921; &#273;&#7897;ng)

&#272;&#7875; t&igrave;m l&#7841;i c&aacute;ch ra/v&ocirc; webiste 
@nom_site_spip@ (@adresse_site@)

Xin v&agrave;o &#273;&#7883;a ch&#7881; sau &#273;&acirc;y:
    @sendcookie@

B&#7841;n cho v&agrave;o m&#7853;t m&atilde; m&#7899;i &#273;&#7875; v&agrave;o l&#7841;i trang web.', # MODIF
'pass_mot_oublie' => 'Qu&ecirc;n m&#7845;t m&#7853;t m&atilde;',
'pass_nouveau_enregistre' => 'M&#7853;t m&atilde; m&#7899;i &#273;&atilde; &#273;&#432;&#7907;c l&#432;u tr&#7919;.',
'pass_nouveau_pass' => 'M&#7853;t m&atilde; m&#7899;i',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Qu&ecirc;n m&#7853;t m&atilde;',
'pass_quitter_fenetre' => 'R&#7901;i b&#7887; khung &#273;&oacute;',
'pass_rappel_login' => 'L&#432;u &yacute;: login c&#7911;a b&#7841;n l&agrave; "@login@".',
'pass_recevoir_mail' => 'B&#7841;n s&#7869; nh&#7853;n qua email chi ti&#7871;t ch&#7881; d&#7851;n c&aacute;ch thu h&#7891;i ph&eacute;p ra/v&ocirc; trang web.',
'pass_retour_public' => 'Tr&#7903; l&#7841;i trang web',
'pass_rien_a_faire_ici' => 'Kh&ocirc;ng c&oacute; g&igrave; &#7903; &#273;&acirc;y.',
'pass_vousinscrire' => 'Ghi danh v&#7899;i website',
'precedent' => 'tr&#432;&#7899;c',
'previsualisation' => 'Xem tr&#432;&#7899;c',
'previsualiser' => 'Cho xem tr&#432;&#7899;c',

// R
'retour' => 'Tr&#7903; l&#7841;i',

// S
'spip_conforme_dtd' => 'SPIP x&aacute;c nh&#7853;n trang n&agrave;y theo &#273;&uacute;ng ti&ecirc;u chu&#7849;n v&#7899;i DOCTYPE c&#7911;a SPIP:',
'squelette' => 'b&#7843;n m&#7851;u',
'squelette_inclus_ligne' => 'b&#7843;n m&#7851;u &#273;&iacute;nh k&egrave;m, d&ograve;ng',
'squelette_ligne' => 'b&#7843;n m&#7851;u, d&ograve;ng',
'stats_visites_et_popularite' => '@visites@ l&#7847;n vi&#7871;ng; m&#7913;c ph&#7893; th&ocirc;ng: @popularite@',
'suivant' => 'k&#7871; ti&#7871;p',

// T
'taille_ko' => '@taille@&nbsp;kb',
'taille_mo' => '@taille@&nbsp;Mb',
'taille_octets' => '@taille@ bytes',
'texte_actualite_site_1' => 'Khi b&#7841;n tr&#7903; n&ecirc;n quen thu&#7897;c v&#7899;i c&aacute;ch th&#7913;c tr&igrave;nh b&agrave;y trong website n&agrave;y, b&#7845;m v&agrave;o &laquo;',
'texte_actualite_site_2' => 'Xem t&#7845;t c&#7843;',
'texte_actualite_site_3' => '&raquo; &#273;&#7875; xem nh&#7919;ng &#273;&#7863;c &#273;i&#7875;m kh&aacute;c.',
'texte_creation_automatique_vignette' => 'Website c&oacute; kh&#7843; n&#259;ng t&#7841;o l&#7853;p t&#7921; &#273;&#7897;ng c&aacute;c h&igrave;nh m&#7851;u.
N&#7871;u b&#7841;n &#273;em v&agrave;o nh&#7919;ng h&igrave;nh &#7843;nh trong d&#7841;ng  @gd_formats@, ch&uacute;ng s&#7869; c&oacute; h&igrave;nh m&#7851;u v&#7899;i kh&#7893; t&#7889;i &#273;a l&agrave; @taille_preview@ ch&#7845;m. ',
'texte_documents_associes' => 'C&aacute;c t&agrave;i li&#7879;u sau &#273;&acirc;y c&oacute; li&ecirc;n &#273;&#7899;i v&#7899;i b&agrave;i n&agrave;y, nh&#432;ng ch&uacute;ng kh&ocirc;ng &#273;&#432;&#7907;c &#273;&#7897;n tr&#7921;c ti&#7871;p v&agrave;o. D&#7921;a theo b&#7889; tr&iacute; c&#7911;a website, ch&uacute;ng tr&ocirc;ng nh&#432; l&agrave; t&agrave;i li&#7879;u &#273;&iacute;nh k&egrave;m. ',
'texte_erreur_mise_niveau_base' => 'C&oacute; l&#7895;i database trong l&uacute;c n&acirc;ng c&#7845;p. H&igrave;nh <b>@fichier@</b> kh&ocirc;ng chuy&#7875;n v&ocirc; &#273;&#432;&#7907;c trong (b&agrave;i @id_article@).<p> H&atilde;y l&#432;u &yacute; cho k&#7929; l&#7901;i nh&#7855;n n&agrave;y, th&#7917; l&#7841;i vi&#7879;c n&acirc;ng c&#7845;p, v&agrave; cu&#7889;i c&ugrave;ng ki&#7875;m l&#7841;i xem h&igrave;nh c&oacute; hi&#7879;n ra trong b&agrave;i kh&ocirc;ng. ', # MODIF
'texte_erreur_visiteur' => 'Vous avez tent&eacute; d\'acc&eacute;der &agrave; l\'espace priv&eacute; avec un login qui ne le permet pas.', # NEW
'texte_inc_auth_1' => 'B&#7841;n b&#7843;o r&#7857;ng login c&#7911;a b&#7841;n l&#224; <b>@auth_login@</b>, nh&#432;ng login n&#224;y kh&#244;ng c&#243; trong database. T&#236;m c&#225;ch', # MODIF
'texte_inc_auth_2' => 'n&#7889;i l&#7841;i',
'texte_inc_auth_3' => 'b&#7857;ng c&aacute;ch ra kh&#7887;i v&agrave; kh&#7903;i &#273;&#7897;ng l&#7841;i browser, n&#7871;u c&#7847;n thi&#7871;t.',
'texte_inc_config' => 'Nh&#7919;ng s&#7917;a &#273;&#7893;i d&#432;&#7899;i &#273;&acirc;y t&aacute;c &#273;&#7897;ng &#273;&#7871;n s&#7921; v&#7853;n h&agrave;nh c&#7911;a website. Khuy&#7871;n c&aacute;o b&#7841;n kh&ocirc;ng n&ecirc;n &#273;&#7909;ng v&ocirc; tr&#7915; phi b&#7841;n n&#7855;m v&#7919;ng s&#7921; v&#7853;n h&agrave;nh c&#7911;a h&#7879; th&#7889;ng SPIP. <br /><br /><b>T&#7889;t h&#417;n h&#7871;t, b&#7841;n n&ecirc;n &#273;&#7875; cho ng&#432;&#7901;i webmaster ch&iacute;nh lo c&aacute;c vi&#7879;c n&agrave;y.</b>', # MODIF
'texte_inc_meta_1' => 'C&oacute; v&#7845;n &#273;&#7873; khi vi&#7871;t h&#7891; s&#417; <code>@fichier@</code>.L&agrave; qu&#7843;n l&yacute; vi&ecirc;n c&#7911;a website, xin b&#7841;n ', # MODIF
'texte_inc_meta_2' => 'ki&#7875;m l&#7841;i quy&#7873;n h&#7841;n vi&#7871;t',
'texte_inc_meta_3' => 'c&#7911;a ng&#259;n <code>@repertoire@</code>.', # MODIF
'texte_statut_en_cours_redaction' => '&#273;ang vi&#7871;t/so&#7841;n',
'texte_statut_poubelle' => 'v&ocirc; th&ugrave;ng r&aacute;c',
'texte_statut_propose_evaluation' => '&#273;&#432;&#7907;c &#273;&#7873; ngh&#7883;',
'texte_statut_publie' => '&#273;&#432;&#7907;c &#273;&#259;ng l&ecirc;n',
'texte_statut_refuse' => 'b&#7883; t&#7915; ch&#7889;i',
'titre_ajouter_mot_cle' => 'TH&Ecirc;M M&#7896;T T&#7914; TH&Ecirc;N CH&#7888;T:',
'titre_breve_proposee' => 'Tin ng&#7855;n &#273;&atilde; n&#7897;p',
'titre_breve_publiee' => 'Tin ng&#7855;n &#273;&atilde; &#273;&#259;ng t&#7843;i',
'titre_breve_refusee' => 'Tin ng&#7855;n b&#7883; t&#7915; ch&#7889;i',
'titre_cadre_raccourcis' => 'NG&Otilde; T&#7854;T:',
'titre_changer_couleur_interface' => 'Thay &#273;&#7893;i m&agrave;u c&#7911;a giao di&#7879;n',
'titre_forum' => 'Di&#7877;n &#273;&agrave;n',
'titre_image_admin_article' => 'B&#7841;n c&oacute; th&#7875; qu&#7843;n tr&#7883; b&agrave;i n&agrave;y',
'titre_image_administrateur' => 'Qu&#7843;n tr&#7883; vi&ecirc;n',
'titre_image_aide' => 'Gi&uacute;p &#273;&#7905; tr&ecirc;n ti&#7871;t m&#7909;c n&agrave;y',
'titre_image_auteur_supprime' => 'T&aacute;c gi&#7843; b&#7883; xo&aacute;',
'titre_image_redacteur' => 'T&aacute;c gi&#7843; kh&ocirc;ng c&oacute; quy&#7873;n',
'titre_image_redacteur_02' => 'T&aacute;c gi&#7843;',
'titre_image_visiteur' => 'Kh&aacute;ch',
'titre_joindre_document' => '&#272;&Iacute;NH K&Egrave;M M&#7896;T H&#7890; S&#416;',
'titre_liens_entrants' => 'C&aacute;c &#273;i&#7875;m n&#7889;i v&agrave;o',
'titre_mots_cles' => 'T&#7914; THEN CH&#7888;T',
'titre_probleme_technique' => 'B&aacute;o &#273;&#7897;ng: tr&#7909;c tr&#7863;c k&#7929; thu&#7853;t (SQL server) th&agrave;nh ra kh&ocirc;ng v&agrave;o &#273;&#432;&#7907;c ch&#7895; n&agrave;y c&#7911;a trang web.<p>Xin th&ocirc;ng c&#7843;m.', # MODIF
'titre_publier_document' => 'PH&Aacute;T H&Agrave;NH M&#7896;T T&Agrave;I LI&#7878;U TRONG &#272;&#7872; M&#7908;C N&Agrave;Y',
'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
'titre_signatures_confirmees' => 'Signatures confirm&eacute;es', # NEW
'titre_statistiques' => 'Th&#7889;ng K&ecirc;',
'titre_titre_document' => 'T&#7921;a b&agrave;i:',
'todo' => '&agrave; venir', # NEW
'trad_reference' => '(b&agrave;i n&#7889;i k&#7871;t)',

// Z
'zbug_balise_b_aval' => ': B tag too late in loop',
'zbug_balise_inexistante' => 'erreur @from@: la balise #@balise@ n\'existe pas', # MODIF
'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@', # NEW
'zbug_boucle' => 'loop',
'zbug_boucle_recursive_undef' => 'undefined recursive loop', # MODIF
'zbug_calcul' => 'calcul', # NEW
'zbug_champ_hors_boucle' => 'Field @champ@ outside loop',
'zbug_champ_hors_motif' => 'Field @champ@ outside loop tagged @motif@', # MODIF
'zbug_code' => 'm&atilde;',
'zbug_critere_inconnu' => 'unknown criterion @critere@', # MODIF
'zbug_distant_interdit' => 'external data forbidden', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'doublons sur une table sans clef primaire atomique', # MODIF
'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
'zbug_erreur_boucle_double' => 'BOUCLE@id@: Ch&#7881; &#273;&#432;&#7907;c d&ugrave;ng m&#7897;t l&#7847;n ', # MODIF
'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: ch&#432;a d&#432;&#7907;c d&oacute;ng l&#7841;i ', # MODIF
'zbug_erreur_boucle_syntaxe' => 'C&aacute;ch vi&#7871;t v&ograve;ng (boucle) n&agrave;y kh&ocirc;ng &#273;&uacute;ng.', # MODIF
'zbug_erreur_compilation' => 'Erreur de compilation', # NEW
'zbug_erreur_execution_page' => 'error in page calculation', # MODIF
'zbug_erreur_filtre' => 'Sai l&#7847;m : B&#7841;n ch&#432;a x&aacute;c &#273;&#7883;nh b&#7897; l&#7885;c (filtre) <b>&laquo; @filtre@ &raquo;</b> n&#7847;y. ', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} only applies to loops (FORUMS) and (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'Error(s) in template',
'zbug_hors_compilation' => 'Hors Compilation', # NEW
'zbug_info_erreur_squelette' => 'C&oacute; l&#7895;i tr&ecirc;n Website',
'zbug_inversion_ordre_inexistant' => 'reversal of nonexistent order', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive', # MODIF
'zbug_parametres_inclus_incorrects' => 'Wrong inclusion parameters', # MODIF
'zbug_profile' => 'Th&#7901;i gian t&iacute;nh to&aacute;n: @time@',
'zbug_resultat' => 'k&#7871;t qu&#7843;',
'zbug_serveur_indefini' => 'undefined SQL server', # MODIF
'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e', # NEW
'zbug_table_inconnue' => 'Unknown SQL table "@table@"',
'zxml_connus_attributs' => 'attributs connus', # NEW
'zxml_de' => 'de', # NEW
'zxml_inconnu_attribut' => 'attribut inconnu', # NEW
'zxml_inconnu_balise' => 'balise inconnue', # NEW
'zxml_inconnu_entite' => 'entit&eacute; inconnue', # NEW
'zxml_inconnu_id' => 'chi ti&#7871;t ID kh&ocirc;ng bi&#7871;t',
'zxml_mais_de' => 'mais de', # NEW
'zxml_non_conforme' => 'n\'est pas conforme au motif', # NEW
'zxml_non_fils' => 'n\'est pas un fils de', # NEW
'zxml_nonvide_balise' => 'balise non vide', # NEW
'zxml_obligatoire_attribut' => 'attribut obligatoire mais absent dans', # NEW
'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte', # NEW
'zxml_survoler' => '&#273;&#7875; xem chi ti&#7871;t &#273;&uacute;ng, di chuy&#7875;n con chu&#7897;t l&ecirc;n tr&ecirc;n',
'zxml_valeur_attribut' => 'valeur de l\'attribut', # NEW
'zxml_vide_balise' => 'balise vide', # NEW
'zxml_vu' => '&#273;&atilde; th&#7845;y tr&#432;&#7899;c &#273;&acirc;y'
);

?>
